@@ -21,8 +21,9 @@
 getVDigest <- function(algo = c("md5", "sha1", "crc32", "sha256", "sha512",
                                  "xxhash32", "xxhash64", "murmur32", "spookyhash"),
                         errormode=c("stop","warn","silent")){
-    algo <- match.arg(algo)
-    errormode <- match.arg(errormode)
+    algo <- match.arg(algo, c("md5", "sha1", "crc32", "sha256", "sha512",
+                              "xxhash32", "xxhash64", "murmur32", "spookyhash"))
+    errormode <- match.arg(errormode, c("stop","warn","silent"))
     algoint <- algo_int(algo)
     non_streaming_algos <- c("md5", "sha1", "crc32", "sha256", "sha512",
                              "xxhash32", "xxhash64", "murmur32")
@@ -50,8 +51,8 @@ non_streaming_digest <- function(algo, errormode, algoint){
         }
 
         if (serialize && !file) {
-            ## support the 'nosharing' option in pqR's base::serialize()
-            object <- if ("nosharing" %in% names(formals(base::serialize)))
+            ## support the 'nosharing' option in pqR's serialize()
+            object <- if (.hasNoSharing())
                 serialize_(
                     object,
                     connection = NULL,
@@ -170,6 +171,6 @@ streaming_digest <- function(algo, errormode, algoint){
 
 serialize_ <- function(object, ...){
     if (length(object))
-        return(lapply(object, base::serialize, ...))
-    base::serialize(object, ...)
+        return(lapply(object, serialize, ...))
+    serialize(object, ...)
 }
